##################
Reporting an error
##################

Please report all errors to the `Issues section`_ of the PyMeasure GitHub repository. Use the search function to determine if there is an existing or resolved issued before posting.

.. _`Issues section`: https://github.com/pymeasure/pymeasure/issues
